AlwaysVisibleBottomBarVisibility class

The bottom bar is always visible regardless of the sheet's offset.

Note that, contrary to the name, the bar will be hidden when the keyboard is open and ignoreBottomInset is false.

Inheritance

Constructors

AlwaysVisibleBottomBarVisibility({bool ignoreBottomInset = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ignoreBottomInset bool
Whether the bottom bar should be visible when the bottom of MediaQueryData.viewInsets is increased by system UI elements, such as the onscreen keyboard.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited