CupertinoModalSheetPage<T> class

Inheritance

Constructors

CupertinoModalSheetPage({LocalKey? key, String? name, Object? arguments, String? restorationId, bool maintainState = true, bool barrierDismissible = true, bool swipeDismissible = false, String? barrierLabel, Color? barrierColor = _barrierColor, Duration transitionDuration = _transitionDuration, Curve transitionCurve = _incomingTransitionCurve, SwipeDismissSensitivity swipeDismissSensitivity = const SwipeDismissSensitivity(), Color? overlayColor, CupertinoSheetViewportBuilder? viewportBuilder, required Widget child})
const

Properties

arguments → Object?
The arguments passed to this route.
finalinherited
barrierColor → Color?
final
barrierDismissible → bool
final
barrierLabel → String?
final
canPop → bool
When false, blocks the associated route from being popped.
finalinherited
child → Widget
The content to be shown in the Route created by this page.
final
hashCode → int
The hash code for this object.
no setterinherited
key → LocalKey?
The key associated with this page.
finalinherited
maintainState → bool
Whether the route should remain in memory when it is inactive.
final
name → String?
The name of the route (e.g., "/settings").
finalinherited
onPopInvoked → PopInvokedWithResultCallback<T>
Called after a pop on the associated route was handled.
finalinherited
overlayColor → Color?
The color of the overlay applied to the outgoing transition.
final
restorationId → String?
Restoration ID to save and restore the state of the Route configured by this page.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swipeDismissible → bool
final
swipeDismissSensitivity → SwipeDismissSensitivity
final
transitionCurve → Curve
final
transitionDuration → Duration
final
viewportBuilder → CupertinoSheetViewportBuilder?
final

Methods

canUpdate(Page other) → bool
Whether this page can be updated with the other page.
inherited
createRoute(BuildContext context) → Route<T>
Creates the Route that corresponds to this page.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited