PagedSheet class

Inheritance

Constructors

PagedSheet({Key? key, SheetController? controller, SheetPhysics physics = kDefaultSheetPhysics, Curve transitionCurve = Curves.easeInOutCubic, SheetDecoration decoration = const DefaultSheetDecoration(), EdgeInsets padding = EdgeInsets.zero, Widget builder(BuildContext, Widget)?, required Widget navigator})
const

Properties

builder Widget Function(BuildContext, Widget)?
A builder callback for inserting extra widgets between this PagedSheet and the navigator.
final
controller SheetController?
final
decoration SheetDecoration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
padding EdgeInsets
The padding around the child.
final
physics SheetPhysics
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionCurve Curve
The Curve used for both the offset and size transition animations when navigating to a new route within the navigator.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited