PagedSheetRouteTheme class

An InheritedWidget that provides default route parameter values for PagedSheetRoutes and PagedSheetPages in a PagedSheet.

Place this widget above a PagedSheet to set shared defaults for all routes. Individual routes can still override any parameter.

PagedSheetRouteTheme(
  data: PagedSheetRouteThemeData(
    transitionsBuilder: myTransitionBuilder,
    snapGrid: mySnapGrid,
  ),
  child: PagedSheet(
    navigator: Navigator(...),
  ),
)
Inheritance

Constructors

PagedSheetRouteTheme({Key? key, required PagedSheetRouteThemeData data, required Widget child})
Creates a PagedSheetRouteTheme.
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
data → PagedSheetRouteThemeData
The theme data for route defaults.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant PagedSheetRouteTheme oldWidget) → bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → PagedSheetRouteThemeData?
Returns the PagedSheetRouteThemeData from the nearest PagedSheetRouteTheme ancestor.