BoxSheetDecoration class
SheetDecoration that uses a DecoratedBox widget to decorate the sheet.
- Inheritance
-
- Object
- SizedSheetDecoration
- BoxSheetDecoration
Constructors
- BoxSheetDecoration({required SheetSize size, required Decoration decoration, DecorationPosition position = DecorationPosition.background})
-
Creates a SheetDecoration that uses a DecoratedBox widget
to decorate the sheet.
const
Properties
- decoration → Decoration
-
See DecoratedBox.decoration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → DecorationPosition
-
See DecoratedBox.position.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → SheetSize
-
finalinherited
Methods
-
build(
BuildContext context, Widget child) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preferredExtent(
double offset, ViewportLayout layout) → double -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited